Djanog Phone Login
=================================

**Password Free Authentication System**

Django Phone Login provides phone number login with no additional passwords to remember.
It's a easy way to grow your customer base. Without any hassle.

Guides
======

.. toctree::
   :maxdepth: 2

   guides/getting_started
   guides/authentication
   guides/advanced_notes
   guides/roadmap

External Documentation
======================

`Django Phonenumber Field <https://github.com/stefanfoulis/django-phonenumber-field>`_

`Django Send SMS <https://django-sendsms.readthedocs.io/en/latest/>`_

`DRF3 <http://www.django-rest-framework.org>`_


.. Leave this out for now
.. Indices and Tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
